Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrInvalidProcess = errors.New("InvalidProcess")
Functions ¶
func NewSignal ¶ added in v0.0.5
NewSignal returns the Signal for signal named x or numbered x.
Examples:
- "INT" -> syscall.SIGINT
- 2 -> syscall.SIGINT
- "2" -> syscall.SIGINT
func SignalIntoString ¶ added in v0.0.7
Types ¶
type Process ¶
type Process struct {
Stdin io.Reader
Stdout io.Writer
Stderr io.Writer
Args []string
CancelSignal os.Signal
WaitDelay time.Duration
// contains filtered or unexported fields
}
Process is an external command executed under lock control.
Click to show internal directories.
Click to hide internal directories.